@@ -43,7 +43,7 @@ def _load_for_entry(proj: Project, map: Mapping, ins: str, tbl: str, dm: DataMod
     return items
 
 
-def _load_data_model(proj: Project, map: Mapping, ins: str, tbl: str) -> bool:
+def _load_data_model(proj: Project, map: Mapping, ins: str, tbl: str) -> bool | None:
     if is_exist_data_model(proj.folder, map.id, ins, tbl) is False:
         if map.parent is None:
             return None
@@ -129,6 +129,7 @@ class Operation:
                         # create_tableの中で再作成されているため
                         logger.info(f'restore {self.map.id}.{tbl.table_name}')
                         table.restore(self.conn, self.map.id, tbl, self.ymd)
+                engine.commit(self.conn)
 
     def reset_all(self):
         # ユニットテストなど一括して再作成を行う場合に使用する。
